//This file is automaically generated. Do not modify it.
#ifndef KIWIX_LIBKIWIX_RESOURCES_H
#define KIWIX_LIBKIWIX_RESOURCES_H

#include <string>
#include <stdexcept>

namespace RESOURCE {
    namespace skin {
extern const std::string caret_png;
}
    namespace skin {
extern const std::string bittorrent_png;
}
    namespace skin {
extern const std::string magnet_png;
}
    namespace skin {
extern const std::string _404_svg;
}
    namespace skin {
extern const std::string _500_svg;
}
    namespace skin {
extern const std::string blocklink_svg;
}
    namespace skin {
extern const std::string feed_svg;
}
    namespace skin {
extern const std::string langSelector_svg;
}
    namespace skin {
extern const std::string download_png;
}
    namespace skin {
extern const std::string download_white_svg;
}
    namespace skin {
extern const std::string hash_png;
}
    namespace skin {
extern const std::string search_icon_svg;
}
    namespace skin {
extern const std::string iso6391To3_js;
}
    namespace skin {
extern const std::string isotope_pkgd_min_js;
}
    namespace skin {
extern const std::string index_js;
}
    namespace skin { namespace autoComplete {
extern const std::string autoComplete_min_js;
} }
    namespace skin {
extern const std::string error_css;
}
    namespace skin {
extern const std::string print_css;
}
    namespace skin {
extern const std::string kiwix_css;
}
    namespace skin {
extern const std::string taskbar_css;
}
    namespace skin {
extern const std::string index_css;
}
    namespace skin { namespace fonts {
extern const std::string DMSans_Regular_ttf;
} }
    namespace skin { namespace fonts {
extern const std::string Poppins_ttf;
} }
    namespace skin { namespace fonts {
extern const std::string Roboto_ttf;
} }
    namespace skin {
extern const std::string search_results_css;
}
    namespace skin {
extern const std::string blank_html;
}
    namespace skin {
extern const std::string polyfills_js;
}
    namespace skin {
extern const std::string viewer_js;
}
    namespace skin {
extern const std::string i18n_js;
}
    namespace skin {
extern const std::string languages_js;
}
    namespace skin {
extern const std::string mustache_min_js;
}
    
extern const std::string viewer_html;

    namespace templates {
extern const std::string search_result_html;
}
    namespace templates {
extern const std::string search_result_xml;
}
    namespace templates {
extern const std::string error_html;
}
    namespace templates {
extern const std::string error_xml;
}
    namespace templates {
extern const std::string index_html;
}
    namespace templates {
extern const std::string suggestion_json;
}
    namespace templates {
extern const std::string captured_external_html;
}
    namespace templates {
extern const std::string catalog_entries_xml;
}
    namespace templates {
extern const std::string catalog_v2_root_xml;
}
    namespace templates {
extern const std::string catalog_v2_entries_xml;
}
    namespace templates {
extern const std::string catalog_v2_entry_xml;
}
    namespace templates {
extern const std::string catalog_v2_partial_entry_xml;
}
    namespace templates {
extern const std::string catalog_v2_categories_xml;
}
    namespace templates {
extern const std::string catalog_v2_languages_xml;
}
    namespace templates {
extern const std::string url_of_search_results_css_tmpl;
}
    namespace templates {
extern const std::string viewer_settings_js;
}
    namespace templates {
extern const std::string no_js_library_page_html;
}
    namespace templates {
extern const std::string no_js_download_html;
}
    namespace templates {
extern const std::string sexy404_html;
}
    namespace templates {
extern const std::string sexy500_html;
}
    
extern const std::string opensearchdescription_xml;

    
extern const std::string ft_opensearchdescription_xml;

    
extern const std::string catalog_v2_searchdescription_xml;

    namespace skin { namespace autoComplete { namespace css {
extern const std::string autoComplete_css;
} } }
    namespace skin { namespace favicon {
extern const std::string android_chrome_192x192_png;
} }
    namespace skin { namespace favicon {
extern const std::string android_chrome_512x512_png;
} }
    namespace skin { namespace favicon {
extern const std::string apple_touch_icon_png;
} }
    namespace skin { namespace favicon {
extern const std::string browserconfig_xml;
} }
    namespace skin { namespace favicon {
extern const std::string favicon_16x16_png;
} }
    namespace skin { namespace favicon {
extern const std::string favicon_32x32_png;
} }
    namespace skin { namespace favicon {
extern const std::string favicon_ico;
} }
    namespace skin { namespace favicon {
extern const std::string mstile_70x70_png;
} }
    namespace skin { namespace favicon {
extern const std::string mstile_144x144_png;
} }
    namespace skin { namespace favicon {
extern const std::string mstile_150x150_png;
} }
    namespace skin { namespace favicon {
extern const std::string mstile_310x150_png;
} }
    namespace skin { namespace favicon {
extern const std::string mstile_310x310_png;
} }
    namespace skin { namespace favicon {
extern const std::string safari_pinned_tab_svg;
} }
    namespace skin { namespace favicon {
extern const std::string site_webmanifest;
} }
    namespace skin { namespace i18n {
extern const std::string ar_json;
} }
    namespace skin { namespace i18n {
extern const std::string bn_json;
} }
    namespace skin { namespace i18n {
extern const std::string br_json;
} }
    namespace skin { namespace i18n {
extern const std::string cs_json;
} }
    namespace skin { namespace i18n {
extern const std::string dag_json;
} }
    namespace skin { namespace i18n {
extern const std::string de_json;
} }
    namespace skin { namespace i18n {
extern const std::string dga_json;
} }
    namespace skin { namespace i18n {
extern const std::string el_json;
} }
    namespace skin { namespace i18n {
extern const std::string en_json;
} }
    namespace skin { namespace i18n {
extern const std::string es_json;
} }
    namespace skin { namespace i18n {
extern const std::string fi_json;
} }
    namespace skin { namespace i18n {
extern const std::string fr_json;
} }
    namespace skin { namespace i18n {
extern const std::string ha_json;
} }
    namespace skin { namespace i18n {
extern const std::string he_json;
} }
    namespace skin { namespace i18n {
extern const std::string hi_json;
} }
    namespace skin { namespace i18n {
extern const std::string hu_json;
} }
    namespace skin { namespace i18n {
extern const std::string hy_json;
} }
    namespace skin { namespace i18n {
extern const std::string ia_json;
} }
    namespace skin { namespace i18n {
extern const std::string id_json;
} }
    namespace skin { namespace i18n {
extern const std::string ig_json;
} }
    namespace skin { namespace i18n {
extern const std::string it_json;
} }
    namespace skin { namespace i18n {
extern const std::string ja_json;
} }
    namespace skin { namespace i18n {
extern const std::string ko_json;
} }
    namespace skin { namespace i18n {
extern const std::string ku_latn_json;
} }
    namespace skin { namespace i18n {
extern const std::string lb_json;
} }
    namespace skin { namespace i18n {
extern const std::string mk_json;
} }
    namespace skin { namespace i18n {
extern const std::string ms_json;
} }
    namespace skin { namespace i18n {
extern const std::string nb_json;
} }
    namespace skin { namespace i18n {
extern const std::string nl_json;
} }
    namespace skin { namespace i18n {
extern const std::string nqo_json;
} }
    namespace skin { namespace i18n {
extern const std::string or_json;
} }
    namespace skin { namespace i18n {
extern const std::string pl_json;
} }
    namespace skin { namespace i18n {
extern const std::string pt_br_json;
} }
    namespace skin { namespace i18n {
extern const std::string pt_json;
} }
    namespace skin { namespace i18n {
extern const std::string ro_json;
} }
    namespace skin { namespace i18n {
extern const std::string ru_json;
} }
    namespace skin { namespace i18n {
extern const std::string sc_json;
} }
    namespace skin { namespace i18n {
extern const std::string sk_json;
} }
    namespace skin { namespace i18n {
extern const std::string skr_arab_json;
} }
    namespace skin { namespace i18n {
extern const std::string sl_json;
} }
    namespace skin { namespace i18n {
extern const std::string sq_json;
} }
    namespace skin { namespace i18n {
extern const std::string sv_json;
} }
    namespace skin { namespace i18n {
extern const std::string sw_json;
} }
    namespace skin { namespace i18n {
extern const std::string te_json;
} }
    namespace skin { namespace i18n {
extern const std::string test_json;
} }
    namespace skin { namespace i18n {
extern const std::string tr_json;
} }
    namespace skin { namespace i18n {
extern const std::string zh_hans_json;
} }
    namespace skin { namespace i18n {
extern const std::string zh_hant_json;
} }
};

class ResourceNotFound : public std::runtime_error {
  public:
    ResourceNotFound(const std::string& what_arg):
      std::runtime_error(what_arg)
    { };
};

const std::string& getResource_libkiwix_resources_h(const std::string& name);
const char* getResourceCacheId_libkiwix_resources_h(const std::string& name);

#define getResource(a) (getResource_libkiwix_resources_h(a))
#define getResourceCacheId(a) (getResourceCacheId_libkiwix_resources_h(a))

#endif // KIWIX_LIBKIWIX_RESOURCES_H

